@@ -1,32 +1,46 @@
 package File::Slurper::Shortcuts;
 
-our $DATE = '2018-09-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-10-06'; # DATE
+our $VERSION = '0.003'; # VERSION
 
-use strict;
+use strict 'subs', 'vars';
 use warnings;
+no warnings 'once';
 use Carp;
 
 use File::Slurper ();
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(replace_text replace_binary);
+our @EXPORT_OK = qw(
+                       modify_text
+                       modify_binary
+                       replace_text
+                       replace_binary
+               );
 
-sub replace_text {
+sub modify_text {
     my ($filename, $code, $encoding, $crlf) = @_;
 
     local $_ = File::Slurper::read_text($filename, $encoding, $crlf);
+    my $orig = $_;
 
     my $res = $code->($_);
     croak "replace_text(): Code does not return true" unless $res;
 
+    return if $orig eq $_;
+
     File::Slurper::write_text($filename, $_, $encoding, $crlf);
+    $orig;
 }
 
-sub replace_binary {
-    return replace_text(@_[0,1], 'latin-1');
+sub modify_binary {
+    return modify_text(@_[0,1], 'latin-1');
 }
 
+# old names, deprecated and will be removed in the future
+*replace_text = \&modify_text;
+*replace_binary = \&modify_binary;
+
 1;
 # ABSTRACT: Some convenience additions for File::Slurper
 
@@ -42,30 +56,36 @@ File::Slurper::Shortcuts - Some convenience additions for File::Slurper
 
 =head1 VERSION
 
-This document describes version 0.002 of File::Slurper::Shortcuts (from Perl distribution File-Slurper-Shortcuts), released on 2018-09-22.
+This document describes version 0.003 of File::Slurper::Shortcuts (from Perl distribution File-Slurper-Shortcuts), released on 2019-10-06.
 
 =head1 SYNOPSIS
 
- use File::Slurper::Shortcuts qw(replace_text replace_binary);
- replace_text("dist.ini", sub { s/One/Two/ });
+ use File::Slurper::Shortcuts qw(modify_text modify_binary);
+ modify_text("dist.ini", sub { s/One/Two/ });
 
 =head1 DESCRIPTION
 
+=for Pod::Coverage ^(replace_text|replace_binary)$
+
 =head1 FUNCTIONS
 
-=head2 replace_text
+=head2 modify_text
 
 Usage:
 
- replace_text($filename, $code, $encoding, $crlf);
+ $orig_content = modify_text($filename, $code, $encoding, $crlf);
 
 This is like L<File::Slurper>'s C<write_text> except that instead of C<$content>
 in the second argument, this routine accepts C<$code>. Code should modify C<$_>
-(which contains the content of the file) and return true. This routine will die
-if: file can't be read with C<read_text()>, code does not return true, file
+(which contains the content of the file) B<and return true>. This routine will
+die if: file can't be read with C<read_text()>, code does not return true, file
 can't be written to with C<write_text()>.
 
-=head2 replace_binary
+If content (C<$_>) does not change, file will not be written.
+
+Return the original content of file.
+
+=head2 modify_binary
 
 =head1 HOMEPAGE
 
@@ -93,7 +113,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
